Dashboard
=========

The first thing you will see after the login is the dashboard.
Depending on what your system administrator configured,
you will be able to see information from different apps at one glance.

.. image:: ../_static/dashboard.png
  :width: 100%
  :alt: The dashboard

Dashboard widgets
-----------------

The dashboard consists of different parts, the so-called *dashboard widgets*.
They are configured by the system administrator and can be freely
arranged on the dashboard (cf. :ref:`core-user-customising-dashboard`).

.. _core-user-customising-dashboard:

Customising the dashboard
-------------------------

There are several options for customising your personal dashboard. By default,
you will see a layout provided by your system administrator. Using the button
*Edit dashboard* on the top right corner of the dashboard,
you can change the selection and position of the widgets.

.. image:: ../_static/edit_dashboard.png
  :width: 100%
  :alt: Edit the dashboard

On the edit page, you will see a list of all available widgets and your current dashboard.
If the section *Your dashboard* is empty, the default dashboard will be shown.
To make an own layout, you can drag widgets from the *Available widgets* to *Your dashboard*.
Within *Your dashboard* you also can arrange the widgets by dragging them.
To remove widgets from the dashboard, you just have to drag them back to *Available widgets*.

In addition to editing the dashboard, you can also change same preferences referring to the dashboard.
This is done under the menu item *Account → Preferences → General*:

* **Automatically update the dashboard and its widgets:** If enabled by you and the system administrator,
  the dashboard will be updated automatically every 15 seconds.
